( cd usr/bin ; rm -rf pltotf )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/pltotf pltotf )
( cd usr/bin ; rm -rf tftopl )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/tftopl tftopl )
( cd usr/bin ; rm -rf vftovp )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/vftovp vftovp )
( cd usr/bin ; rm -rf vptovf )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/vptovf vptovf )
( cd usr/man/preformat/cat1 ; rm -rf vftovp.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf /cdrom/live/usr/man/preformat/cat1/vftovp.1.gz vftovp.1.gz )
( cd usr/man/preformat/cat1 ; rm -rf vptovf.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf /cdrom/live/usr/man/preformat/cat1/vptovf.1.gz vptovf.1.gz )
( cd usr/man/preformat/cat1 ; rm -rf pltotf.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf /cdrom/live/usr/man/preformat/cat1/pltotf.1.gz pltotf.1.gz )
( cd usr/man/preformat/cat1 ; rm -rf tftopl.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf /cdrom/live/usr/man/preformat/cat1/tftopl.1.gz tftopl.1.gz )
